@@ -223,8 +223,8 @@ var searchData=
   ['tdsdbopen_220',['tdsdbopen',['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
   ['tdsdump_5fclose_221',['tdsdump_close',['../a00431.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
   ['tdsdump_5fcol_222',['tdsdump_col',['../a00431.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
-  ['tdsdump_5fdump_5fbuf_223',['tdsdump_dump_buf',['../a00431.html#a79449d2f35a8acc8ed0585044f75524d',1,'log.c']]],
-  ['tdsdump_5flog_224',['tdsdump_log',['../a00431.html#ab45c291105027e69836002e1dd586141',1,'log.c']]],
+  ['tdsdump_5fdump_5fbuf_5fimpl_223',['tdsdump_dump_buf_impl',['../a00431.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
+  ['tdsdump_5flog_5fimpl_224',['tdsdump_log_impl',['../a00431.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
   ['tdsdump_5foff_225',['tdsdump_off',['../a00431.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
   ['tdsdump_5fon_226',['tdsdump_on',['../a00431.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
   ['tdsdump_5fopen_227',['tdsdump_open',['../a00431.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
